@@ -8,6 +8,7 @@ import (
 	stdLog "log"
 	"os"
 	"runtime/debug"
+	"strings"
 
 	"github.com/pkg/errors"
 	"github.com/pkg/profile"
@@ -289,11 +290,23 @@ func checkAPIKey(apiKey string, apiEndpoint string, defaultEndpoint string) erro
 	return nil
 }
 
+var ignoredErrors = []string{
+	"Tag policy check failed",
+	"Policy check failed",
+	"Guardrail check failed",
+}
+
 func handleCLIError(ctx *config.RunContext, cliErr error) {
 	if cliErr.Error() != "" {
 		ui.PrintError(ctx.ErrWriter, cliErr.Error())
 	}
 
+	for _, pattern := range ignoredErrors {
+		if strings.Contains(cliErr.Error(), pattern) {
+			return
+		}
+	}
+
 	err := apiclient.ReportCLIError(ctx, cliErr, true)
 	if err != nil {
 		logging.Logger.WithError(err).Debug("error reporting CLI error")
