@@ -90,14 +90,7 @@ func newRunInput(ctx *config.RunContext, out output.Root) (*runInput, error) {
 	}
 
 	ctxValues["repoMetadata"] = metadata
-
 	if ctx.IsInfracostComment() {
-		// Clone the map to cleanup up the "command" key to show "comment".  It is
-		// currently set to the sub comment (e.g. "github")
-		ctxValues = make(map[string]interface{}, len(ctxValues))
-		for k, v := range ctx.ContextValues.Values() {
-			ctxValues[k] = v
-		}
 		ctxValues["command"] = "comment"
 	}
 
