@@ -40,6 +40,8 @@ func (c *TagPolicyAPIClient) CheckTagPolicies(ctx *config.RunContext, out output
 				message
 				prComment
 				blockPr
+				totalDetectedResources
+				totalTaggableResources
 				resources {
 					address
 					resourceType
