@@ -20,6 +20,7 @@ type Configuration struct {
 	TLSInsecureSkipVerify *bool  `yaml:"tls_insecure_skip_verify,omitempty"`
 	TLSCACertFile         string `yaml:"tls_ca_cert_file,omitempty"`
 	EnableCloud           *bool  `yaml:"enable_cloud"`
+	EnableCloudUpload     *bool  `yaml:"enable_cloud_upload"`
 }
 
 func loadConfiguration(cfg *Config) error {
@@ -51,6 +52,10 @@ func loadConfiguration(cfg *Config) error {
 		cfg.EnableCloud = cfg.Configuration.EnableCloud
 	}
 
+	if cfg.Configuration.EnableCloudUpload != nil {
+		cfg.EnableCloudUpload = cfg.Configuration.EnableCloudUpload
+	}
+
 	if cfg.Configuration.DisableHCLParsing != nil {
 		cfg.DisableHCLParsing = *cfg.Configuration.DisableHCLParsing
 	}
