@@ -12,6 +12,7 @@ import (
 	jsoniter "github.com/json-iterator/go"
 	"github.com/pkg/errors"
 	pathToRegexp "github.com/soongo/path-to-regexp"
+	"gopkg.in/yaml.v2"
 )
 
 var (
@@ -51,6 +52,9 @@ func NewParser(repoDir string, variables Variables) *Parser {
 		"list":       p.list,
 		"relPath":    p.relPath,
 		"isDir":      p.isDir,
+		"readFile":   p.readFile,
+		"parseJson":  p.parseJson,
+		"parseYaml":  p.parseYaml,
 	})
 	p.template = t
 
@@ -259,3 +263,67 @@ func (p *Parser) isDir(path string) bool {
 
 	return info.IsDir()
 }
+
+// readFile reads the named file and returns the contents.
+func (p *Parser) readFile(path string) string {
+	if !isSubdirectory(p.repoDir, path) {
+		panic(fmt.Sprintf("%q must be within the repository root %q", path, filepath.Base(p.repoDir)))
+	}
+
+	fullPath := filepath.Join(p.repoDir, path)
+	b, err := os.ReadFile(fullPath)
+	if err != nil {
+		panic(err)
+	}
+
+	return string(b)
+}
+
+// parseYaml decodes provided yaml contents and assigns decoded values into a
+// generic out value. This can be used as a simple object in the templates.
+func (p *Parser) parseYaml(contents string) map[string]interface{} {
+	var out map[string]interface{}
+	err := yaml.Unmarshal([]byte(contents), &out)
+	if err != nil {
+		panic(err)
+	}
+
+	return out
+}
+
+// parseJson decodes the provided json contents and assigns decoded values into a
+// generic out value. This can be used as a simple object in the templates.
+func (p *Parser) parseJson(contents string) map[string]interface{} {
+	var out map[string]interface{}
+	err := jsoniter.Unmarshal([]byte(contents), &out)
+	if err != nil {
+		panic(err)
+	}
+
+	return out
+}
+
+func isSubdirectory(base, target string) bool {
+	full := filepath.Join(base, target)
+	fileInfo, err := os.Lstat(full)
+	if err != nil {
+		return false
+	}
+
+	absBasePath, err := filepath.Abs(base)
+	if err != nil {
+		return false
+	}
+
+	absTargetPath, err := filepath.Abs(full)
+	if err != nil {
+		return false
+	}
+
+	relPath, err := filepath.Rel(absBasePath, absTargetPath)
+	if err != nil {
+		return false
+	}
+
+	return !strings.HasPrefix(relPath, "..") && fileInfo.Mode()&os.ModeSymlink == 0
+}
