@@ -172,13 +172,13 @@ func CompareTo(c *config.Config, current, prior Root) (Root, error) {
 
 	// preserve the summary from the original run
 	currentProjects := make(map[string]Project)
-	for _, p := range prior.Projects {
+	for _, p := range current.Projects {
 		currentProjects[p.LabelWithMetadata()] = p
 	}
-	for _, outP := range out.Projects {
-		if v, ok := currentProjects[outP.LabelWithMetadata()]; ok {
-			outP.Summary = v.Summary
-			outP.fullSummary = v.fullSummary
+	for i := range out.Projects {
+		if v, ok := currentProjects[out.Projects[i].LabelWithMetadata()]; ok {
+			out.Projects[i].Summary = v.Summary
+			out.Projects[i].fullSummary = v.fullSummary
 		}
 	}
 
