@@ -6,6 +6,8 @@ import (
 	"github.com/infracost/infracost/internal/resources/aws"
 	"github.com/infracost/infracost/internal/schema"
 	"github.com/tidwall/gjson"
+	"golang.org/x/text/cases"
+	"golang.org/x/text/language"
 )
 
 func getMWAAEnvironmentRegistryItem() *schema.RegistryItem {
@@ -25,7 +27,7 @@ func NewMWAAEnvironment(d *schema.ResourceData, u *schema.UsageData) *schema.Res
 
 	size = strings.ToLower(size)
 	size = strings.ReplaceAll(size, "mw1.", "")
-	size = strings.Title(size)
+	size = cases.Title(language.English).String(size)
 
 	a := &aws.MWAAEnvironment{
 		Address: d.Address,
