@@ -14,6 +14,7 @@ import (
 	"time"
 
 	tgcli "github.com/gruntwork-io/terragrunt/cli"
+	"github.com/gruntwork-io/terragrunt/cli/tfsource"
 	tgconfig "github.com/gruntwork-io/terragrunt/config"
 	tgconfigstack "github.com/gruntwork-io/terragrunt/configstack"
 	tgerrors "github.com/gruntwork-io/terragrunt/errors"
@@ -75,13 +76,13 @@ func NewTerragruntHCLProvider(ctx *config.ProjectContext, includePastResources b
 		includePastResources: includePastResources,
 		outputs:              map[string]cty.Value{},
 		excludedPaths:        ctx.ProjectConfig.ExcludePaths,
-		env:                  getEnvVars(),
+		env:                  getEnvVars(ctx),
 		sourceCache:          map[string]string{},
 		logger:               logger,
 	}
 }
 
-func getEnvVars() map[string]string {
+func getEnvVars(ctx *config.ProjectContext) map[string]string {
 	environment := os.Environ()
 	environmentMap := make(map[string]string)
 
@@ -113,6 +114,16 @@ func getEnvVars() map[string]string {
 		}
 	}
 
+	for k, v := range ctx.ProjectConfig.Env {
+		if !filterSafe {
+			environmentMap[k] = v
+		}
+
+		if _, ok := safe[strings.ToLower(k)]; ok {
+			environmentMap[k] = v
+		}
+	}
+
 	return environmentMap
 }
 
@@ -543,7 +554,19 @@ func (p *TerragruntHCLProvider) runTerragrunt(opts *tgoptions.TerragruntOptions)
 		return
 	}
 	if sourceURL != "" {
-		unlock := terragruntSourceLock.Lock(sourceURL)
+		source, err := tfsource.NewTerraformSource(sourceURL, opts.DownloadDir, opts.WorkingDir, opts.Logger)
+		if err != nil {
+			info.error = err
+			return
+		}
+
+		// make the source download directory absolute so that we lock on a consistent key.
+		dir := source.DownloadDir
+		if v, err := filepath.Abs(dir); err == nil {
+			dir = v
+		}
+
+		unlock := terragruntSourceLock.Lock(dir)
 		updatedTerragruntOptions, err := tgcli.DownloadTerraformSource(sourceURL, opts, terragruntConfig)
 		unlock()
 
